Refactor AAA app in preparation for clustered operation.

* Add formal API for accessing auth state information rather than directly
looking up static maps.
* Move static maps in StateMachine to non-static maps in AaaManager
* Manage identifier space used for requests/replies better
* Refactored state machine timeout mechansim

Change-Id: Ie53c3a66ac1619e10607d9926b71747a333317f3
diff --git a/api/src/main/java/org/opencord/aaa/AuthenticationService.java b/api/src/main/java/org/opencord/aaa/AuthenticationService.java
index 82aabbd..c474203 100644
--- a/api/src/main/java/org/opencord/aaa/AuthenticationService.java
+++ b/api/src/main/java/org/opencord/aaa/AuthenticationService.java
@@ -16,11 +16,30 @@
 
 package org.opencord.aaa;
 
+import org.onlab.packet.MacAddress;
 import org.onosproject.event.ListenerService;
 
+import java.util.List;
+
 /**
  * Service for interacting with authentication module.
  */
 public interface AuthenticationService extends
         ListenerService<AuthenticationEvent, AuthenticationEventListener> {
+
+    /**
+     * Gets records of authentications that are completed or in progress.
+     *
+     * @return list of authentication records
+     */
+    List<AuthenticationRecord> getAuthenticationRecords();
+
+    /**
+     * Removes an authentication record.
+     *
+     * @param mac MAC address of record to remove
+     * @return true if a record was remove, otherwise false
+     */
+    boolean removeAuthenticationStateByMac(MacAddress mac);
+
 }
@@ -16,11 +16,30 @@
 /**
- * Service for interacting with authentication module.
+ * Service for interacting with authentication state.
  */
 public interface AuthenticationService extends